@@ -10,7 +10,7 @@ use B::Hooks::EndOfScope qw(on_scope_end);
 use Devel::Pragma qw(my_hints);
 use XSLoader;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 XSLoader::load 'Goto::Cached', $VERSION;
 
@@ -36,17 +36,16 @@ Goto::Cached - a fast drop-in replacement for Perl's O(n) goto
 
 =head1 SYNOPSIS
 
-    use Goto::Cached;
+    sub factorial($) {
+        use Goto::Cached;
+        my $n = shift;
+        my $accum = 1;
 
-    my $label = 'LABEL3';
-
-    goto LABEL1;
-
-    LABEL1: goto $label;
-
-    LABEL2: print "Not reached!", $/;
-
-    LABEL3: print "label3!", $/;
+        iter: return $accum if ($n < 2);
+        $accum *= $n;
+        --$n;
+        goto iter;
+    }
 
 =head1 DESCRIPTION
 
@@ -54,12 +53,9 @@ Goto::Cached provides a fast, lexically-scoped drop-in replacement for Perl's
 builtin C<goto>. Its use is the same as the builtin. C<goto &sub> and jumps out
 of the current scope are not cached.
 
-In a simple benchmark (see C<t/benchmark.t>), static C<goto>s are approximately 6 times
-faster than the builtin, and dynamic C<goto>s are approximately 1.6 times faster.
-
 =head1 VERSION
 
-0.20
+0.21
 
 =head1 SEE ALSO
 
